Description
The class "cvq2" extends class "q2" and is used to store information about the model calibration and its prediction performance.
The prediction performance is calculated with a cross-validation.Objects from the Class
Objects can be created by calls of the form new("cvq2", ...).Extends
Class "q2", directly.